package WebService::Braintree::CreditCard::Commercial;
$WebService::Braintree::CreditCard::Commercial::VERSION = '0.93';
use strict;

use constant Yes => "Yes";
use constant No => "No";
use constant Unknown => "Unknown";

1;
